<?php

// register widget
add_action( 'widgets_init', 'dk_speakup_register_widgets' );
function dk_speakup_register_widgets() {
	register_widget( 'dk_speakup_petition_widget' );
}

class dk_speakup_petition_widget extends WP_Widget {

	function dk_speakup_petition_widget() {
		$widget_ops = array(
			'classname' => 'dk_speakup_widget',
			'description' => __( 'Display a petition form.', 'dk_speakup' )
		);
		$this->WP_Widget( 'dk_speakup_petition_widget', 'SpeakUp! Email Petitions', $widget_ops );

		// load widget scripts
		if ( ! is_admin() && is_active_widget( false, false, $this->id_base, true ) ) {
			wp_enqueue_script( 'dk_speakup_widget_js', plugins_url( 'speakup-email-petitions/js/widget.js' ), array( 'jquery' ) );
			wp_enqueue_style( 'dk_speakup_widget_css', plugins_url( 'speakup-email-petitions/css/widget.css' ) );

			// set up AJAX callback script
			$protocol = isset( $_SERVER['HTTPS'] ) ? 'https://' : 'http://';
			$params = array( 'ajaxurl' => admin_url( 'admin-ajax.php', $protocol ) );
			wp_localize_script( 'dk_speakup_widget_js', 'dk_speakup_widget_js', $params );
		}
	}

	// create widget form (admin)
	function form($instance) {
		$options = get_option( 'dk_speakup_options' );
		$defaults = array( 'title' => $options['petition_header'], 'call_to_action' => '', 'petition_id' => '1' );
		$instance = wp_parse_args( (array) $instance, $defaults );
		$title = $instance['title'];
		$call_to_action = $instance['call_to_action'];
		$petition_id = $instance['petition_id'];

		global $wpdb;
		$db_petitions = $wpdb->prefix . 'dk_speakup_petitions';
		// select available petitions from db
		$sql = "
			SELECT id, petition_title
			FROM `$db_petitions`
		";
		$results = $wpdb->get_results( $sql );

		// display the form (admin)
		echo '<p><label>' . __( 'Title', 'dk_speakup' ) . ':</label><br /><input class="widefat" type="text" name="' . $this->get_field_name( 'title' ) . '" value="' . $instance['title'] . '"></p>';
		echo '<p><label>' . __( 'Call to Action', 'dk_speakup' ) . ':</label><br /><textarea maxlength="140" class="widefat" name="' . $this->get_field_name( 'call_to_action' ) . '">' . $instance['call_to_action'] . '</textarea></p>';
		echo '<p><label>' . __( 'Petition', 'dk_speakup' ) . ':</label><br /><select class="widefat" name="' . $this->get_field_name( 'petition_id' ) . '">';
		foreach ( $results as $petition  ) {
			$selected = $petition_id == $petition->id ? ' selected="selected"' : '';
			echo '<option value="' . $petition->id . '" ' . $selected . '>' . esc_html( $petition->petition_title ) . '</option>';
		}
		echo '</select></p>';
	}

	// save the widget settings (admin)
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['call_to_action'] = strip_tags( $new_instance['call_to_action'] );
		$instance['petition_id'] = $new_instance['petition_id'];

		return $instance;
	}

	// display widget (public)
	function widget($args, $instance) {
		$options = get_option( 'dk_speakup_options' );
		global $wpdb;
		$db_petitions = $wpdb->prefix . 'dk_speakup_petitions';
		$db_signatures = $wpdb->prefix . 'dk_speakup_signatures';
		extract($args);

		// get widget data
		$title = apply_filters( 'widget_title', $instance['title'] );
		$call_to_action = empty( $instance['call_to_action'] ) ? '&nbsp;' : $instance['call_to_action'];
		$petition_id = empty( $instance['petition_id'] ) ? '1' : $instance['petition_id'];

		// get petition data
		$sql = "
			SELECT
				$db_petitions.id, $db_petitions.petition_title, $db_petitions.petition_greeting,
				$db_petitions.petition_message, $db_petitions.display_address, $db_petitions.display_custom_field,
				$db_petitions.custom_field_label, $db_petitions.expires, $db_petitions.expiration_date,
				$db_petitions.has_signature_goal, $db_petitions.signature_goal, $db_petitions.send_email,
				$db_petitions.confirm, $db_petitions.display_email_optin, $db_petitions.email_optin_label,
				$db_petitions.twitter_message, COUNT( $db_signatures.id ) AS 'signatures'
			FROM $db_petitions
			LEFT JOIN $db_signatures
				ON $db_petitions.id = $db_signatures.petitions_id
				AND ( $db_signatures.confirmed = '' OR $db_signatures.confirmed = '1' )
			WHERE $db_petitions.id = '$petition_id'
			GROUP BY $db_petitions.id
		";
		$results = $wpdb->get_row( $sql );

		// get user data for logged-in users
		$user_firstname = '';
		$user_lastname  = '';
		$user_email     = '';
		$current_user = wp_get_current_user();
		if ( $current_user -> ID != 0 ) {
			$user_firstname = $current_user -> user_firstname;
			$user_lastname = $current_user -> user_lastname;
			$user_email = $current_user -> user_email;
		}

		/* Configure optional fields */
		// Greeting
		$greeting = ( $results->petition_greeting != '' && $results->send_email == 1 ) ? '<p><span class="dk-speakup-widget-greeting">' . $results->petition_greeting . '</span></p>' : '';

		// Pseudo Signature
		if ( $results->send_email == '1' ) {
			$pseudo_signature = '<p>[' . __( 'Your Name', 'dk_speakup') . ']<br />[' . __( 'Your Email', 'dk_speakup') . ']';
			if ( $results->display_address == '1' ) {
				$pseudo_signature .= '<br />[' . __( 'Your Address', 'dk_speakup' ) . ']';
			}
			if ( $results->display_custom_field == '1' ) {
				$pseudo_signature .= '<br />[' . $results->custom_field_label . ']';
			}
			$pseudo_signature .= '</p>';
		}
		else {
			$pseudo_signature = '';
		}
		// Address field
		if( $results->display_address == '1' ) {
			$address_field = '
				<div class="dk-speakup-widget-address-wrap">
					<label for="dk-speakup-widget-address-' . $results->id . '">' . __( 'Address', 'dk_speakup' ) . '</label>
					<textarea name="dk-speakup-widget-address" id="dk-speakup-widget-address-' . $results->id . '" class="dk-speakup-widget-input dk-speakup-widget-address" maxlength="200"></textarea>
				</div>
			';
		}
		else {
			$address_field = '';
		}

		// Custom field
		if( $results->display_custom_field == '1' ) {
			$custom_field = '
				<div class="dk-speakup-widget-custom-field-wrap">
					<label for="dk-speakup-widget-custom-field-' . $results->id . '">' . $results->custom_field_label . '</label>
					<input name="dk-speakup-widget-custom-field" id="dk-speakup-widget-custom-field-' . $results->id . '" class="dk-speakup-widget-input dk-speakup-widget-custom-field" type="text">
				</div>
			';
		}
		else {
			$custom_field = '';
		}

		// Email opt-in checkbox
		if( $results->display_email_optin == '1' ) {
			// determine if box should be checked by default
			$optin_default = ( $options['optin_default'] == 'checked' ) ? 'checked' : '';
			// compose HTML
			$email_optin = '
				<div class="dk-speakup-widget-optin-wrap">
					<input type="checkbox" name="dk-speakup-widget-optin" id="dk-speakup-widget-optin-' . $results->id . '" class="dk-speakup-widget-optin"' . $optin_default . ' />
					<label for="dk-speakup-widget-optin-' . $results->id . '">' . $results->email_optin_label . '</label>
				</div>
			';
		}
		else {
			$email_optin = '';
		}

		// Signature count and progress bar
		if ( $options['display_count'] == '1' ) {
			$progress_count = dk_speakup_public_goal_progress( $results->signature_goal, $results->signatures, 150, $results->has_signature_goal, 1 );
		}
		else {
			$progress_count = '';
		}

		// if petition has expired, display expiration notice
		$expired = ( $results->expires == '1' && time() >= strtotime( $results->expiration_date ) ) ? 1 : 0;
		$goal_text = ( $results->signature_goal != 0 ) ? '<div class="dk-speakup-expired-goal"><span>' . __( 'Signature goal', 'dk_speakup' ) . ':</span> ' . $results->signature_goal . '</div>' : '';

		// compose the petition widget and pop-up form
		echo '
			<!-- SpeakUp! Email Petitions Widget -->
			<div class="dk-speakup-widget-wrap" id="dk-speakup-petition-' . $results->id . '">
				<h3>' . $title . '</h3>
				<p>' . $call_to_action . '</p>
				<p class="dk-speakup-widget-button-wrap">
					<a rel="dk-speakup-widget-popup-wrap-' . $results->id . '" class="dk-speakup-widget-button"><span>' . $options['button_text'] . '</span></a>
				</p>
				' . $progress_count . '
			</div>

			<!-- SpeakUp! Email Petitions Widget Pop-Up -->
			<div id="dk-speakup-windowshade"></div>
			<div id="dk-speakup-widget-popup-wrap-' . $results->id . '" class="dk-speakup-widget-popup-wrap">
				<h3>' . $results->petition_title . '</h3>
				<div class="dk-speakup-widget-close"></div>
				<div class="dk-speakup-widget-message-wrap">
					<div name="dk-speakup-widget-message" id="dk-speakup-widget-message-' . $results->id . '" class="dk-speakup-widget-message">' . $greeting . wpautop( $results->petition_message ) . $pseudo_signature . '</div>
				</div>
				<div class="dk-speakup-widget_form-wrap">
					<div class="dk-speakup-widget-response"></div>
					<form class="dk-speakup-widget-form">
						<input type="hidden" name="dk-speakup-widget-id" class="dk-speakup-widget-id" value="' . $results->id . '" />
						<input type="hidden" class="dk-speakup-widget-permalink" value="' . get_permalink() .'" />
						<input type="hidden" class="dk-speakup-widget-posttitle" value="' . esc_attr( urlencode( get_the_title() ) ) .'" />
						<input type="hidden" class="dk-speakup-widget-twitter-message" value="' . urlencode( $results->twitter_message ) .'" />
		';
			if ( $expired ) {
				echo '
					<p><strong>' . $options['expiration_message'] . '</strong></p>
					<p>' . __( 'End date', 'dk_speakup' ) . ': ' . date( 'M d, Y', strtotime( $results->expiration_date ) ) . '</p>
					<p>' . __( 'Signatures collected', 'dk_speakup' ) . ': ' . $results->signatures . '</p>
					<p>' . $goal_text . '</p>
				';
			}
			else {
				echo '
					<p>' . $call_to_action . '</p>
					<div class="dk-speakup-widget-first-name-wrap">
						<label for="dk-speakup-widget-first-name-' . $results->id . '">' . __( 'First Name', 'dk_speakup' ) . '</label>
						<input name="dk-speakup-widget-first-name" id="dk-speakup-widget-first-name-' . $results->id . '" class="dk-speakup-widget-input dk-speakup-widget-first-name" value="' . $user_firstname . '" type="text" />
					</div>
					<div class="dk-speakup-widget-last-name-wrap">
						<label for="dk-speakup-widget-last-name-' . $results->id . '">' . __( 'Last Name', 'dk_speakup' ) . '</label>
						<input name="dk-speakup-widget-last-name" id="dk-speakup-widget-last-name-' . $results->id . '" class="dk-speakup-widget-input dk-speakup-widget-last-name" value="' . $user_lastname . '" type="text" />
					</div>
					<div class="dk-speakup-widget-email-wrap">
						<label for="dk-speakup-widget-email-' . $results->id . '">' . __( 'Email', 'dk_speakup' ) . '</label>
						<input name="dk-speakup-widget-email" id="dk-speakup-widget-email-' . $results->id . '" class="dk-speakup-widget-input dk-speakup-widget-email" value="' . $user_email . '" type="text" />
					</div>
					' . $address_field . '
					' . $custom_field . '
					' . $email_optin . '
					<div class="dk-speakup-widget-submit-wrap">
						<a name="dk-speakup-widget-popup-wrap-' . $results->id . '" class="dk-speakup-widget-submit"><span>' . $options['button_text'] . '</span></a>
					</div>
				';
			}
				echo '
					</form>
					<div class="dk-speakup-widget-share">
						<p><strong>' . $share_message = $options['share_message'] . '</strong></p>
						<a class="dk-speakup-widget-facebook" href="#" title="Facebook"></a>
						<a class="dk-speakup-widget-twitter" href="#" title="Twitter"></a>
						<div class="dk-speakup-clear"></div>
					</div>
				</div>
			</div>
		';
	}

}

?>