jQuery( document ).ready( function( $ ) {

	// run only if widget is on the page
	if( $( '.dk-speakup-widget-wrap' ).length ) {
		$( '.dk-speakup-widget-button' ).click( function( e ) {
			var petition_form = '#' + $( this ).attr( 'rel' );

			// get screen height and width
			var screenHeight = $( document ).height();
			var screenWidth = $( window ).width();

			$( '#dk-speakup-windowshade' ).css( {
				'width' : screenWidth,
				'height' : screenHeight
			});
			$( '#dk-speakup-windowshade' ).fadeTo( 500, .8 );

			// get window height and width
			var windowHeight = $( window ).height();
			var windowWidth = $( window ).width();

			// center the pop-up window
			$( petition_form ).css( 'top',  ( ( windowHeight / 2 ) - ( $( petition_form ).height() / 2 ) ) );
			$( petition_form ).css( 'left', ( windowWidth / 2 ) - ( $( petition_form ).width() / 2 ) );

			// display the form
			$( petition_form ).fadeIn( 500 );

		});

		/* Close the pop-up petition form */
		// by clicking windowshade area
		$( '#dk-speakup-windowshade' ).click( function () {
			$( this ).fadeOut( 'slow' );
			$( '.dk-speakup-widget-popup-wrap' ).hide();
		});
		// or by clicking the close button
		$( '.dk-speakup-widget-close' ).click( function() {
			$( '#dk-speakup-windowshade' ).fadeOut( 'slow' );
			$( '.dk-speakup-widget-popup-wrap' ).hide();
		});
		// or by pressing ESC
		$( document ).keyup( function( e ) {
			if ( e.keyCode === 27 ) {
				$( '#dk-speakup-windowshade' ).fadeOut( 'slow' );
				$( '.dk-speakup-widget-popup-wrap' ).hide();
			}
		});

		// process petition form submissions
		$( '.dk-speakup-widget-submit' ).click( function() {
			var petition_wrap = '#' + $( this ).attr( 'name' );
			var id = $( petition_wrap ).find( '.dk-speakup-widget-id' ).val();
			var permalink = $( petition_wrap ).find( '.dk-speakup-widget-permalink' ).val();
			var posttitle = $( petition_wrap ).find( '.dk-speakup-widget-posttitle' ).val();
			var twitter_message = $( petition_wrap ).find( '.dk-speakup-widget-twitter-message' ).val();
			var first_name = $( petition_wrap ).find( '.dk-speakup-widget-first-name' ).val();
			var last_name = $( petition_wrap ).find( '.dk-speakup-widget-last-name' ).val();
			var email = $( petition_wrap ).find( '.dk-speakup-widget-email' ).val();
			var address = $( petition_wrap ).find( '.dk-speakup-widget-address' ).val();
			var custom_field = $( petition_wrap ).find( '.dk-speakup-widget-custom-field' ).val();
			var optin = '';
			if ( $( petition_wrap ).find( '.dk-speakup-widget-optin' ).attr( 'checked' ) ) {
				optin = 'on';
			}

			// make sure error notices are turned off before checking for new errors
			$( petition_wrap ).find( 'input' ).removeClass( 'dk-speakup-error' );

			// validate form values
			var errors = 0;
			var emailRegEx = /^([\w-\.]+@([\w-]+\.)+[\w-]{2,4})?$/;
			if ( email == '' || !emailRegEx.test( email ) ) {
				$( petition_wrap ).find( '.dk-speakup-widget-email' ).addClass( 'dk-speakup-error' );
				errors ++;
			}
			if ( first_name == '' ) {
				$( petition_wrap ).find( '.dk-speakup-widget-first-name' ).addClass( 'dk-speakup-error' );
				errors ++;
			}
			if ( last_name == '' ) {
				$( petition_wrap ).find( '.dk-speakup-widget-last-name' ).addClass( 'dk-speakup-error' );
				errors ++;
			}

			// if no errors found, submit the data via ajax
			if ( errors == 0 ) {
				var data = {
					action: 'dk_speakup_sendmail',
					id: id,
					first_name: first_name,
					last_name: last_name,
					email: email,
					address: address,
					custom_field: custom_field,
					optin: optin
				};

				// submit form data and handle ajax response
				$.post( dk_speakup_widget_js.ajaxurl, data,
					function( response ) {
						$( petition_wrap ).find( '.dk-speakup-widget-form' ).hide();
						$( petition_wrap ).find( '.dk-speakup-widget-response' ).fadeIn().html( response );
						$( petition_wrap ).find( '.dk-speakup-widget-share' ).fadeIn();

						// launch Facebook sharing window
						$( '.dk-speakup-widget-facebook' ).click( function() {
							var url = 'http://www.facebook.com/sharer.php?u=' + permalink + '&amp;t=' + posttitle;
							window.open( url, 'facebook', 'height=420,width=550,left=100,top=100,resizable=yes,location=no,status=no,toolbar=no' );
						});
						// launch Twitter sharing window
						$( '.dk-speakup-widget-twitter' ).click( function() {
							var url = 'http://twitter.com/share?url=' + permalink + '&text=' + twitter_message;
							window.open( url, 'twitter', 'height=420,width=550,left=100,top=100,resizable=yes,location=no,status=no,toolbar=no' );
						});
					}
				);
			}

			return false;
		});

		// hide or show form labels depending on input fields
		$( '.dk-speakup-widget-input' ).focus( function( e ) {
			var label = $( this ).siblings( 'label' );
			if ( $( this ).val() == '' ) {
				$( this ).siblings( 'label' ).addClass( 'dk-speakup-focus' ).removeClass( 'dk-speakup-blur' );
			}
			$( this ).blur( function(){
				if ( this.value === '' ) {
					label.addClass( 'dk-speakup-blur' ).removeClass( 'dk-speakup-focus' );
				}
			}).focus( function() {
				label.addClass( 'dk-speakup-focus' ).removeClass( 'dk-speakup-blur' );
			}).keydown( function( e ) {
				label.addClass( 'dk-speakup-focus' ).removeClass( 'dk-speakup-blur' );
				$( this ).unbind( e );
			});
		});

		// hide labels on filled input fields when page is reloaded
		$( '.dk-speakup-widget-input' ).each( function() {
			if ( $( this ).val() != '' ) {
				$( this ).siblings( 'label' ).addClass( 'dk-speakup-focus' );
			}
		});

	}

});